Coverage report

File | class | statements | missing | excluded | coverage
--- | --- | --- | --- | --- | ---
tests\unit\loggers\test_local_logger.py | (no class) | 70 | 0 | 0 | 100%
tests\unit\loggers\test_tensorboard_logger.py | (no class) | 104 | 0 | 0 | 100%
tests\unit\test_tm_integration.py | Model | 3 | 0 | 0 | 100%
tests\unit\test_tm_integration.py | MockedDataset | 3 | 0 | 0 | 100%
tests\unit\test_tm_integration.py | (no class) | 80 | 0 | 0 | 100%
tests\unit\test_training_interval.py | (no class) | 152 | 0 | 0 | 100%
tests\unit\test_training_manager.py | SimpleModel | 3 | 0 | 0 | 100%
tests\unit\test_training_manager.py | (no class) | 213 | 4 | 0 | 98%
trnbl\__init__.py | (no class) | 4 | 0 | 0 | 100%
trnbl\loggers\__init__.py | (no class) | 1 | 0 | 0 | 100%
trnbl\loggers\base.py | LoggerSpinner | 7 | 7 | 0 | 0%
trnbl\loggers\base.py | TrainingLoggerBase | 29 | 13 | 0 | 55%
trnbl\loggers\base.py | (no class) | 58 | 6 | 0 | 90%
trnbl\loggers\local\__init__.py | (no class) | 2 | 0 | 0 | 100%
trnbl\loggers\local\build_dist.py | (no class) | 106 | 106 | 0 | 0%
trnbl\loggers\local\html_frontend.py | (no class) | 4 | 1 | 0 | 75%
trnbl\loggers\local\locallogger.py | FilePaths | 0 | 0 | 0 | 100%
trnbl\loggers\local\locallogger.py | LocalLogger | 80 | 9 | 0 | 89%
trnbl\loggers\local\locallogger.py | (no class) | 43 | 0 | 0 | 100%
trnbl\loggers\local\start_server.py | (no class) | 18 | 13 | 0 | 28%
trnbl\loggers\multi.py | MultiLogger | 15 | 15 | 0 | 0%
trnbl\loggers\multi.py | (no class) | 23 | 23 | 0 | 0%
trnbl\loggers\tensorboard.py | TensorBoardLogger | 25 | 1 | 0 | 96%
trnbl\loggers\tensorboard.py | (no class) | 20 | 0 | 0 | 100%
trnbl\loggers\wandb.py | WandbLogger | 23 | 23 | 0 | 0%
trnbl\loggers\wandb.py | (no class) | 23 | 23 | 0 | 0%
trnbl\training_interval.py | IntervalValueError | 0 | 0 | 0 | 100%
trnbl\training_interval.py | TrainingInterval | 88 | 7 | 0 | 92%
trnbl\training_interval.py | (no class) | 30 | 0 | 0 | 100%
trnbl\training_manager.py | TrainingManagerInitError | 0 | 0 | 0 | 100%
trnbl\training_manager.py | TrainingManager | 93 | 7 | 0 | 92%
trnbl\training_manager.py | (no class) | 53 | 4 | 0 | 92%
Total |  | 1373 | 262 | 0 | 81%

No items found using the specified filter.